# 決定: Phase 2.5.1 緊急修正方針

日時: 2025-01-12  
ステータス: FINAL（実装完了）

## 背景
実運用テストで以下の重大な問題が発生：
1. auto_protectionが大量のファイルをスキャンし、システムがフリーズ状態
2. 同じログメッセージが重複して出力
3. tmuxがない環境でClaude Codeが別ウィンドウで起動するだけ
4. デバッグとリリースビルドの区別がない

## 検討した選択肢

### 1. 最小限の修正（採用）
- 既存アーキテクチャを維持
- 問題箇所のみピンポイント修正
- 後方互換性を保持

### 2. 大規模リファクタリング
- auto_protectionを根本的に再設計
- 画面分割機能を別実装に置き換え

### 3. Phase 2.5.1の一時停止
- 問題が解決するまで機能を無効化
- Phase 2.5に戻す

## 決定理由
最小限の修正アプローチを採用：
- **リスク最小化**: 動作中の機能を壊さない
- **即効性**: 1-2日で実装可能
- **段階的改善**: 将来の改良の余地を残す
- **ユーザー影響**: 最小限の変更で問題解決

## 実装内容

### auto_protection.pyの最適化
```python
# .gitignoreパターンの尊重
self._load_gitignore_patterns()

# スキャン制限
scan_limit = 1000  # ファイル数上限

# ログレベル制御
if self.config.get('debug', False):
    self.logger.info(...)
else:
    self.logger.debug(...)
```

### 起動モードの実装
```bash
claude-plus          # 通常モード
claude-plus --debug  # デバッグモード
claude-plus --safe   # 安全モード（最小機能）
```

### tmuxフォールバック
```python
if not self.is_tmux_available():
    return self._start_fallback_mode()
```

## 却下理由

### 大規模リファクタリング
- 時間がかかりすぎる（1週間以上）
- 新たなバグを生む可能性が高い
- テスト範囲が広すぎる

### Phase 2.5.1の一時停止
- ユーザーの期待を裏切る
- すでに実装済みの機能がもったいない
- 問題は修正可能なレベル

## 教訓
1. **パフォーマンステストの重要性**: 大規模プロジェクトでの動作確認が不足
2. **デフォルト設定の慎重さ**: ログ出力は最小限にすべき
3. **フォールバックの必要性**: 依存関係（tmux）は常にオプショナルに

## 結論
最小限の修正により、全ての問題を解決。Phase 2.5.1は安定動作を実現。