# 🎯 Claude-Plus を PyPI にアップロードする方法（中学生でもわかる！）

## はじめに
今から、あなたが作った Claude-Plus を世界中の人が使えるようにします！
これを読みながら、一つずつ進めていけば、必ずできます。

---

## 📝 今の状況（2025年6月20日）

✅ **もう準備できているもの**
- プログラムのパッケージ（dist/フォルダに入ってる）
- 必要なツール（twine、wheel）
- 設定ファイルのひな形（.pypirc.sample）

❌ **これからやること**
- PyPIのアカウントを作る
- APIトークンをもらう
- アップロードする

---

## 🚀 ステップ1: PyPIのアカウントを作る（10分）

### 1-1. インターネットブラウザを開く
- Chrome（クローム）、Safari（サファリ）、Edge（エッジ）などを開く

### 1-2. PyPIのサイトに行く
1. アドレスバー（URLを入力する場所）をクリック
2. `https://pypi.org` と入力
3. Enterキーを押す

### 1-3. アカウント作成ページに行く
1. ページの右上を見る
2. 「**Register**」という青いボタンを探す
3. 見つけたらクリック

### 1-4. 必要な情報を入力する

**Username（ユーザー名）**
- 好きな名前を**英語**で入力
- 例：`taro_suzuki`、`python_lover123`
- ⚠️ 日本語は使えません！
- もし「このユーザー名は既に使われています」と出たら、後ろに数字を足してみる

**Email address（メールアドレス）**
- 普段使っているメールアドレスを入力
- Gmail、Yahoo!メール、何でもOK
- 後でメールが来るので、見られるメールにする

**Password（パスワード）**
- 8文字以上
- 大文字（A、B、C...）を1つ以上
- 小文字（a、b、c...）を1つ以上
- 数字（1、2、3...）を1つ以上
- 例：`MyPassword123!`
- **重要**: 紙に書いて保管しておく！

**Confirm password（パスワード確認）**
- 上と同じパスワードをもう一度入力

### 1-5. アカウントを作る
1. 全部入力したら、下の方にある「**Create account**」ボタンをクリック
2. もしエラーが出たら、赤い文字を読んで直す

### 1-6. メールを確認する
1. 登録したメールアドレスのメールボックスを開く
2. PyPIからメールが来ているはず（5分くらい待つこともある）
3. メールのタイトル：「Verify your PyPI account」
4. メールを開いて、青いリンクをクリック
5. 「Your email address has been verified!」と表示されたら成功！

---

## 🔐 ステップ2: 2段階認証を設定する（5分）

### 2-1. スマホアプリをインストール
スマホで以下のどちらかをインストール：
- **Google Authenticator**（グーグル認証システム）
- **Microsoft Authenticator**（マイクロソフト認証）

### 2-2. PyPIにログイン
1. `https://pypi.org/login/` に行く
2. さっき作ったユーザー名とパスワードでログイン

### 2-3. 2段階認証の設定
1. 右上の自分のユーザー名をクリック
2. 「**Account settings**」をクリック
3. 「**Two factor authentication (2FA)**」の項目を探す
4. 「**Add 2FA with authentication application**」をクリック

### 2-4. QRコードをスキャン
1. 画面にQRコード（四角いバーコードみたいなやつ）が表示される
2. スマホでさっきインストールしたアプリを開く
3. アプリで「+」ボタンを押して「QRコードをスキャン」を選ぶ
4. カメラでQRコードを読み取る

### 2-5. 6桁の数字を入力
1. アプリに6桁の数字が表示される（30秒ごとに変わる）
2. その数字をPyPIの画面に入力
3. 「**Verify**」ボタンをクリック

### 2-6. リカバリーコードを保存
1. 8個のコードが表示される
2. **超重要**: これを全部メモして、安全な場所に保管！
3. スマホを無くした時に必要になる

---

## 🔑 ステップ3: APIトークンを作る（3分）

### 3-1. API tokensページに行く
1. まだAccount settingsにいるはず
2. 左側のメニューから「**API tokens**」をクリック

### 3-2. 新しいトークンを作る
1. 「**Add API token**」という青いボタンをクリック
2. Token name（トークン名）に `claude-plus` と入力
3. Scope（範囲）は「**Entire account**」のままでOK
4. 「**Create token**」ボタンをクリック

### 3-3. トークンをコピーする
**⚠️ 超重要：この画面は二度と表示されません！**

1. `pypi-` で始まる長〜い文字列が表示される
2. その横の「**Copy**」ボタンをクリック（または全部選択してコピー）
3. メモ帳を開いて貼り付け
4. ファイル名を「pypi-token.txt」にして保存
5. 「**Continue**」ボタンをクリックして画面を閉じる

---

## ⚙️ ステップ4: アップロードの準備（5分）

### 4-1. ターミナルを開く
**Macの場合：**
1. Finderで「アプリケーション」→「ユーティリティ」→「ターミナル」
2. または、Spotlightで「Terminal」と検索

**Windowsの場合：**
1. スタートメニューで「cmd」と検索
2. 「コマンドプロンプト」をクリック

### 4-2. Claude-Plusのフォルダに移動
```bash
cd /Users/harry/Dropbox/Tool_Development/Claude-Plus
```
（あなたの場合は違うパスかもしれません）

### 4-3. 環境変数でトークンを設定
さっき保存したトークンを使います：

```bash
export TWINE_USERNAME=__token__
export TWINE_PASSWORD=pypi-ここにさっきコピーしたトークンを貼り付け
```

**注意**: 
- `__token__` は変えない（アンダースコア2つ + token + アンダースコア2つ）
- トークンは `pypi-` で始まる長い文字列

---

## 📤 ステップ5: アップロード実行（2分）

### 5-1. パッケージがあるか確認
```bash
ls dist/
```

以下のようなファイルが表示されればOK：
- claude_plus-2.9.0-py3-none-any.whl
- claude_plus-2.9.0.tar.gz

### 5-2. PyPIにアップロード
```bash
python -m twine upload dist/*
```

### 5-3. 成功の確認
以下のようなメッセージが出たら成功！
```
Uploading distributions to https://upload.pypi.org/legacy/
Uploading claude_plus-2.9.0-py3-none-any.whl
100% ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ 136.0/136.0 kB
Uploading claude_plus-2.9.0.tar.gz
100% ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ 128.0/128.0 kB

View at:
https://pypi.org/project/claude-plus/2.9.0/
```

---

## ✅ 完成！確認してみよう

### ブラウザで確認
1. `https://pypi.org/project/claude-plus/` を開く
2. あなたのプログラムのページが表示される！

### インストールテスト
新しいターミナルを開いて：
```bash
pip install claude-plus
```

これで世界中の人が使えるようになりました！ 🎉

---

## 🆘 困った時の対処法

### 「403 Forbidden」エラー
- トークンが間違っている可能性
- `export TWINE_PASSWORD=...` をもう一度実行

### 「400 Bad Request: The name 'claude-plus' is already taken」
- 誰かが既に同じ名前を使っている
- pyproject.tomlでプログラム名を変える必要がある

### パスワードを忘れた
1. PyPIのログインページで「Forgot your password?」をクリック
2. メールアドレスを入力してリセット

### 2段階認証のアプリが使えなくなった
1. さっき保存したリカバリーコードを使う
2. ログイン画面で「Use recovery code」を選ぶ

---

## 📝 次回アップロードする時

1. バージョン番号を上げる
   - pyproject.tomlの`version = "2.9.0"`を`version = "2.10.0"`に変更
2. 古いファイルを削除
   ```bash
   rm -rf dist/*
   ```
3. 新しくビルド
   ```bash
   python -m build
   ```
4. アップロード
   ```bash
   python -m twine upload dist/*
   ```

---

## 🎊 おめでとう！

あなたは今、世界中の開発者が使うプログラムの作者になりました！
これからも素晴らしいプログラムを作って、みんなを助けてくださいね。

質問があれば、遠慮なく聞いてください！